/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Defines an abstract application server by extending the <c>Server</c> class. It provides access to the
    /// deployment directory of the application server. The deployment directory is defined by the option
    /// "deployment_dir". Its value is a string.
    /// </summary>
    /// <remarks>
    /// This class is not thread-safe.
    /// </remarks>
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public abstract class ApplicationServer : Server
    {
        /// <summary>
        /// Represents the option name where the deployment directory of the application server is stored.
        /// </summary>
        public const string DEPLOYMENT_DIR = "deployment_dir";

        /// <summary>
        /// Gets the deployment directory of this application server.
        /// </summary>
        /// <remarks>
        /// Its usage depends on the concrete sub-class. It is extracted from the option "deployment_dir".
        /// </remarks>
        /// <value>The deployment directory of this application server.</value>
        /// <exception cref="ServerException">The option "deployment_dir" is missing.</exception>
        public string DeploymentDirectory
        {
            get
            {
                return TestingFrameworkHelper.GetOptionValue(Options, DEPLOYMENT_DIR);
            }
        }

        /// <summary>
        /// Creates a new instance of <c>ApplicationServer</c> class.
        /// </summary>
        protected ApplicationServer()
        {
        }
    }
}

