/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NUnit.Framework;
using NAnt.Core.Types;
using TopCoder.Test.Framework.Servers.Web;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Tests the functionality and error cases of <c>ApplicationServer</c> class. Since this class is an abstract
    /// class, a concrete implementation <c>IISServer</c> is used in the tests.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ApplicationServerTestCase
    {
        /// <summary>
        /// Represents the <c>ApplicationServer</c> instance used in tests.
        /// </summary>
        private ApplicationServer server;

        /// <summary>
        /// Sets up the test environment. The test instance is created.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            server = new IISServer();
        }

        /// <summary>
        /// Cleans up the test environment. The test instance is disposed.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            server = null;
        }

        /// <summary>
        /// Tests accuracy of <c>ApplicationServer()</c>. Since the constructor is trivial, there should be no
        /// exception.
        /// </summary>
        [Test]
        public void TestApplicationServerAccuracy()
        {
            Assert.IsNotNull(new IISServer(), "A new instance of ApplicationServer should be created.");
        }

        /// <summary>
        /// Tests <c>DeploymentDirectory</c> property getter when the option collection is not set. Expect
        /// ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectoryOptionCollectionNotSet()
        {
            string dir = server.DeploymentDirectory;
        }

        /// <summary>
        /// Tests <c>DeploymentDirectory</c> property getter when the option "deployment_dir" is missing. Expect
        /// ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectoryOptionMissing()
        {
            server.Options = new OptionCollection();

            string dir = server.DeploymentDirectory;
        }

        /// <summary>
        /// Tests accuracy of <c>DeploymentDirectory</c> property getter. The deployment directory should be
        /// "../test_files/deploy", as set in the option "deployment_dir".
        /// </summary>
        [Test]
        public void TestDeploymentDirectoryAccuracy()
        {
            Option option = new Option();

            option.OptionName = "deployment_dir";
            option.Value = "../test_files/deploy";
            server.Options = new OptionCollection();
            server.Options.Add(option);

            // Verify
            Assert.AreEqual("../test_files/deploy", server.DeploymentDirectory,
                "The deployment directory should be defined in option 'deployment_dir'.");
        }
    }
}

